@@ -10,20 +10,20 @@
 import sys
 
 
-def __default_out_stream(msg):
+def __default_out_stream(msg: str):
   print(msg)
 
 
-def __default_err_stream(msg):
+def __default_err_stream(msg: str):
   sys.stderr.write(msg + '\n')
 
 
-def __print_to_stream(msg, stream, prefix):
-    if '\n' in msg:
-      for entry in msg.splitlines():
-        stream(prefix + entry)
-    else:
-      stream(prefix + msg)
+def __print_to_stream(msg: str, stream, prefix: str):
+  if '\n' in msg:
+    for entry in msg.splitlines():
+      stream(prefix + entry)
+  else:
+    stream(prefix + msg)
 
 
 __hebi_debug = False
@@ -40,10 +40,10 @@ def debug_mode():
   return __hebi_debug
 
 
-def debug_log(msg):
+def debug_log(msg: str):
   if __hebi_debug:
     __print_to_stream(msg, __hebi_out_stream, '[HEBI Debug] ')
 
 
-def warn_log(msg):
+def warn_log(msg: str):
   __print_to_stream(msg, __hebi_err_stream, '[HEBI Warning] ')
