@@ -10,7 +10,7 @@ class TLS_Holder:
       "_c_int64_p", "_c_uint64_p", "_c_float_p", "_c_double_p"
   ]
 
-  def _grow_arrays(self, size):
+  def _grow_arrays(self, size: int):
     if size > self._size:
       bfr = _ctypes.c_buffer(size)
       self._c_int_p = cast(bfr, c_int_p)
