@@ -6,6 +6,7 @@ _hebi_wrapper_api = None
 # C API Functions
 hebiLookupCreate = None
 hebiLookupRelease = None
+hebiLookupReset = None
 hebiLookupSetLookupFrequencyHz = None
 hebiLookupGetLookupFrequencyHz = None
 hebiCreateLookupEntryList = None
@@ -39,6 +40,8 @@ hebiGroupCommandCreate = None
 hebiGroupCommandGetSize = None
 hebiGroupCommandReadGains = None
 hebiGroupCommandWriteGains = None
+hebiGroupCommandCopyGainsFromInfo = None
+hebiGroupCommandCopyGainsFromCommand = None
 hebiGroupCommandReadSafetyParameters = None
 hebiGroupCommandWriteSafetyParameters = None
 hebiGroupCommandGetModuleCommand = None
@@ -64,12 +67,17 @@ hebiCommandSetString = None
 hebiCommandGetIoLabelString = None
 hebiCommandSetIoLabelString = None
 hebiCommandGetReference = None
+hebiCommandGetSize = None
 hebiCommandGetMetadata = None
+hebiCommandCopyGainsFromInfo = None
+hebiCommandCopyGainsFromCommand = None
 hebiFeedbackGetReference = None
+hebiFeedbackGetSize = None
 hebiFeedbackGetMetadata = None
 hebiInfoGetString = None
 hebiInfoGetIoLabelString = None
 hebiInfoGetReference = None
+hebiInfoGetSize = None
 hebiInfoGetMetadata = None
 hebiRobotModelElementCreateJoint = None
 hebiRobotModelElementCreateRigidBody = None
@@ -98,8 +106,11 @@ hebiRobotModelGetTreeTopology = None
 hebiRobotModelRelease = None
 hebiIKCreate = None
 hebiIKAddObjectiveEndEffectorPosition = None
+hebiIKAddObjectiveFramePosition = None
 hebiIKAddObjectiveEndEffectorSO3 = None
+hebiIKAddObjectiveFrameSO3 = None
 hebiIKAddObjectiveEndEffectorTipAxis = None
+hebiIKAddObjectiveFrameTipAxis = None
 hebiIKAddConstraintJointAngles = None
 hebiIKAddObjectiveCustom = None
 hebiIKClearAll = None
@@ -181,6 +192,8 @@ def set_api_handle(lib: CDLL):
   hebiLookupCreate = lib.hebiLookupCreate
   global hebiLookupRelease
   hebiLookupRelease = lib.hebiLookupRelease
+  global hebiLookupReset
+  hebiLookupReset = lib.hebiLookupReset
   global hebiLookupSetLookupFrequencyHz
   hebiLookupSetLookupFrequencyHz = lib.hebiLookupSetLookupFrequencyHz
   global hebiLookupGetLookupFrequencyHz
@@ -247,6 +260,10 @@ def set_api_handle(lib: CDLL):
   hebiGroupCommandReadGains = lib.hebiGroupCommandReadGains
   global hebiGroupCommandWriteGains
   hebiGroupCommandWriteGains = lib.hebiGroupCommandWriteGains
+  global hebiGroupCommandCopyGainsFromInfo
+  hebiGroupCommandCopyGainsFromInfo = lib.hebiGroupCommandCopyGainsFromInfo
+  global hebiGroupCommandCopyGainsFromCommand
+  hebiGroupCommandCopyGainsFromCommand = lib.hebiGroupCommandCopyGainsFromCommand
   global hebiGroupCommandReadSafetyParameters
   hebiGroupCommandReadSafetyParameters = lib.hebiGroupCommandReadSafetyParameters
   global hebiGroupCommandWriteSafetyParameters
@@ -297,10 +314,18 @@ def set_api_handle(lib: CDLL):
   hebiCommandSetIoLabelString = lib.hebiCommandSetIoLabelString
   global hebiCommandGetReference
   hebiCommandGetReference = lib.hebiCommandGetReference
+  global hebiCommandGetSize
+  hebiCommandGetSize = lib.hebiCommandGetSize
   global hebiCommandGetMetadata
   hebiCommandGetMetadata = lib.hebiCommandGetMetadata
+  global hebiCommandCopyGainsFromInfo
+  hebiCommandCopyGainsFromInfo = lib.hebiCommandCopyGainsFromInfo
+  global hebiCommandCopyGainsFromCommand
+  hebiCommandCopyGainsFromCommand = lib.hebiCommandCopyGainsFromCommand
   global hebiFeedbackGetReference
   hebiFeedbackGetReference = lib.hebiFeedbackGetReference
+  global hebiFeedbackGetSize
+  hebiFeedbackGetSize = lib.hebiFeedbackGetSize
   global hebiFeedbackGetMetadata
   hebiFeedbackGetMetadata = lib.hebiFeedbackGetMetadata
   global hebiInfoGetString
@@ -309,6 +334,8 @@ def set_api_handle(lib: CDLL):
   hebiInfoGetIoLabelString = lib.hebiInfoGetIoLabelString
   global hebiInfoGetReference
   hebiInfoGetReference = lib.hebiInfoGetReference
+  global hebiInfoGetSize
+  hebiInfoGetSize = lib.hebiInfoGetSize
   global hebiInfoGetMetadata
   hebiInfoGetMetadata = lib.hebiInfoGetMetadata
   global hebiRobotModelElementCreateJoint
@@ -365,10 +392,16 @@ def set_api_handle(lib: CDLL):
   hebiIKCreate = lib.hebiIKCreate
   global hebiIKAddObjectiveEndEffectorPosition
   hebiIKAddObjectiveEndEffectorPosition = lib.hebiIKAddObjectiveEndEffectorPosition
+  global hebiIKAddObjectiveFramePosition
+  hebiIKAddObjectiveFramePosition = lib.hebiIKAddObjectiveFramePosition
   global hebiIKAddObjectiveEndEffectorSO3
   hebiIKAddObjectiveEndEffectorSO3 = lib.hebiIKAddObjectiveEndEffectorSO3
+  global hebiIKAddObjectiveFrameSO3
+  hebiIKAddObjectiveFrameSO3 = lib.hebiIKAddObjectiveFrameSO3
   global hebiIKAddObjectiveEndEffectorTipAxis
   hebiIKAddObjectiveEndEffectorTipAxis = lib.hebiIKAddObjectiveEndEffectorTipAxis
+  global hebiIKAddObjectiveFrameTipAxis
+  hebiIKAddObjectiveFrameTipAxis = lib.hebiIKAddObjectiveFrameTipAxis
   global hebiIKAddConstraintJointAngles
   hebiIKAddConstraintJointAngles = lib.hebiIKAddConstraintJointAngles
   global hebiIKAddObjectiveCustom
