@@ -19,6 +19,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiLookupRelease')
 
+  if hasattr(lib, 'hebiLookupReset'):
+    lib_func = getattr(lib, 'hebiLookupReset')
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_char_p), ctypes.c_size_t]
+    lib_func.restype = None
+  else:
+    raise RuntimeWarning('Could not load function hebiLookupReset')
+
   if hasattr(lib, 'hebiLookupSetLookupFrequencyHz'):
     lib_func = getattr(lib, 'hebiLookupSetLookupFrequencyHz')
     lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double]
@@ -407,14 +414,14 @@ def populate_hebi_funcs(lib):
 
   if hasattr(lib, 'hebiCommandGetIoLabelString'):
     lib_func = getattr(lib, 'hebiCommandGetIoLabelString')
-    lib_func.argtypes = [ctypes.c_void_p,ctypes.c_int,ctypes.c_int,ctypes.c_char_p,ctypes.POINTER(ctypes.c_size_t)]
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_int, ctypes.c_char_p, ctypes.POINTER(ctypes.c_size_t)]
     lib_func.restype = ctypes.c_int
   else:
     raise RuntimeWarning('Could not load function hebiCommandGetIoLabelString')
 
   if hasattr(lib, 'hebiCommandSetIoLabelString'):
     lib_func = getattr(lib, 'hebiCommandSetIoLabelString')
-    lib_func.argtypes = [ctypes.c_void_p,ctypes.c_int,ctypes.c_int,ctypes.c_char_p,ctypes.POINTER(ctypes.c_size_t)]
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_int, ctypes.c_char_p, ctypes.POINTER(ctypes.c_size_t)]
     lib_func.restype = ctypes.c_int
   else:
     raise RuntimeWarning('Could not load function hebiCommandSetIoLabelString')
@@ -426,6 +433,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiCommandGetReference')
 
+  if hasattr(lib, 'hebiCommandGetSize'):
+    lib_func = getattr(lib, 'hebiCommandGetSize')
+    lib_func.argtypes = []
+    lib_func.restype = int
+  else:
+    raise RuntimeWarning('Could not load function hebiCommandGetSize')
+
   if hasattr(lib, 'hebiCommandGetMetadata'):
     lib_func = getattr(lib, 'hebiCommandGetMetadata')
     lib_func.argtypes = [ctypes.POINTER(HebiCommandMetadata)]
@@ -440,6 +454,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiFeedbackGetReference')
 
+  if hasattr(lib, 'hebiFeedbackGetSize'):
+    lib_func = getattr(lib, 'hebiFeedbackGetSize')
+    lib_func.argtypes = []
+    lib_func.restype = int
+  else:
+    raise RuntimeWarning('Could not load function hebiFeedbackGetSize')
+
   if hasattr(lib, 'hebiFeedbackGetMetadata'):
     lib_func = getattr(lib, 'hebiFeedbackGetMetadata')
     lib_func.argtypes = [ctypes.POINTER(HebiFeedbackMetadata)]
@@ -456,7 +477,7 @@ def populate_hebi_funcs(lib):
 
   if hasattr(lib, 'hebiInfoGetIoLabelString'):
     lib_func = getattr(lib, 'hebiInfoGetIoLabelString')
-    lib_func.argtypes = [ctypes.c_void_p,ctypes.c_int,ctypes.c_int,ctypes.c_char_p,ctypes.POINTER(ctypes.c_size_t)]
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_int, ctypes.c_char_p, ctypes.POINTER(ctypes.c_size_t)]
     lib_func.restype = ctypes.c_int
   else:
     raise RuntimeWarning('Could not load function hebiInfoGetIoLabelString')
@@ -468,6 +489,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiInfoGetReference')
 
+  if hasattr(lib, 'hebiInfoGetSize'):
+    lib_func = getattr(lib, 'hebiInfoGetSize')
+    lib_func.argtypes = []
+    lib_func.restype = int
+  else:
+    raise RuntimeWarning('Could not load function hebiInfoGetSize')
+
   if hasattr(lib, 'hebiInfoGetMetadata'):
     lib_func = getattr(lib, 'hebiInfoGetMetadata')
     lib_func.argtypes = [ctypes.POINTER(HebiInfoMetadata)]
@@ -666,6 +694,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiIKAddObjectiveEndEffectorPosition')
 
+  if hasattr(lib, 'hebiIKAddObjectiveFramePosition'):
+    lib_func = getattr(lib, 'hebiIKAddObjectiveFramePosition')
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_int, ctypes.c_size_t, ctypes.c_double, ctypes.c_double, ctypes.c_double]
+    lib_func.restype = ctypes.c_int
+  else:
+    raise RuntimeWarning('Could not load function hebiIKAddObjectiveFramePosition')
+
   if hasattr(lib, 'hebiIKAddObjectiveEndEffectorSO3'):
     lib_func = getattr(lib, 'hebiIKAddObjectiveEndEffectorSO3')
     lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_size_t, ctypes.POINTER(ctypes.c_double), ctypes.c_int]
@@ -673,6 +708,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiIKAddObjectiveEndEffectorSO3')
 
+  if hasattr(lib, 'hebiIKAddObjectiveFrameSO3'):
+    lib_func = getattr(lib, 'hebiIKAddObjectiveFrameSO3')
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_int, ctypes.c_size_t, ctypes.POINTER(ctypes.c_double), ctypes.c_int]
+    lib_func.restype = ctypes.c_int
+  else:
+    raise RuntimeWarning('Could not load function hebiIKAddObjectiveFrameSO3')
+
   if hasattr(lib, 'hebiIKAddObjectiveEndEffectorTipAxis'):
     lib_func = getattr(lib, 'hebiIKAddObjectiveEndEffectorTipAxis')
     lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_size_t, ctypes.c_double, ctypes.c_double, ctypes.c_double]
@@ -680,6 +722,13 @@ def populate_hebi_funcs(lib):
   else:
     raise RuntimeWarning('Could not load function hebiIKAddObjectiveEndEffectorTipAxis')
 
+  if hasattr(lib, 'hebiIKAddObjectiveFrameTipAxis'):
+    lib_func = getattr(lib, 'hebiIKAddObjectiveFrameTipAxis')
+    lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_int, ctypes.c_size_t, ctypes.c_double, ctypes.c_double, ctypes.c_double]
+    lib_func.restype = ctypes.c_int
+  else:
+    raise RuntimeWarning('Could not load function hebiIKAddObjectiveFrameTipAxis')
+
   if hasattr(lib, 'hebiIKAddConstraintJointAngles'):
     lib_func = getattr(lib, 'hebiIKAddConstraintJointAngles')
     lib_func.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_size_t, ctypes.POINTER(ctypes.c_double), ctypes.POINTER(ctypes.c_double)]
