@@ -7,6 +7,7 @@ import numpy as _np
 ################################################################################
 
 
+c_bool_p = _ctypes.POINTER(_ctypes.c_bool)
 c_int_p = _ctypes.POINTER(_ctypes.c_int)
 c_int32_p = _ctypes.POINTER(_ctypes.c_int32)
 c_uint32_p = _ctypes.POINTER(_ctypes.c_uint32)
@@ -32,22 +33,16 @@ cast_to_double_ptr = lambda val: cast(val, c_double_p)
 cast_to_float_ptr = lambda val: cast(val, c_float_p)
 
 
-def pointer_offset(ptr, offset):
-  """
-  Equivalent to `(char*)ptr + offset` or `&((char*)ptr)[offset]`
-  """
+def pointer_offset(ptr: '_ctypes.pointer[_ctypes.c_double]', offset: int):
+  """Equivalent to `(char*)ptr + offset` or `&((char*)ptr)[offset]`"""
   return byref(ptr.contents, offset)
 
 
 def to_double_ptr(val):
-  """
-  Retrieve a ctypes pointer to the provided numpy object
-  """
+  """Retrieve a ctypes pointer to the provided numpy object."""
   return cast(val.__array_interface__['data'][0], c_double_p)
 
 
 def to_float_ptr(val):
-  """
-  Retrieve a ctypes pointer to the provided numpy object
-  """
+  """Retrieve a ctypes pointer to the provided numpy object."""
   return cast(val.__array_interface__['data'][0], c_float_p)
