@@ -6,7 +6,8 @@ from .. import debug
 
 import typing
 if typing.TYPE_CHECKING:
-  from typing import List, Optional
+  pass
+
 
 class HEBICoreLibrary(object):
   """Loads the C API functions.
@@ -96,7 +97,7 @@ class HEBICoreLibrary(object):
 
 class SharedLibraryLoader(object):
   def __init__(self, library: str):
-    self._candidates: "List[str]" = list()
+    self._candidates: 'list[str]' = list()
     self._library = library
 
   def add_candidate(self, loc: str):
@@ -136,8 +137,8 @@ class SharedLibraryLoader(object):
     return None, None
 
 
-def _get_library_load_candidates(library: str, readable_name: str, env_var: "Optional[str]"=None):
-  ret: "List[str]" = list()
+def _get_library_load_candidates(library: str, readable_name: str, env_var: 'str | None' = None):
+  ret: 'list[str]' = list()
   from os import environ
   import sys
 
@@ -166,7 +167,7 @@ def _get_library_load_candidates(library: str, readable_name: str, env_var: "Opt
   return ret
 
 
-def _load_shared_library(name: str, readable_name: str, env_var: "Optional[str]"=None):
+def _load_shared_library(name: str, readable_name: str, env_var: 'str | None' = None):
   loader = SharedLibraryLoader(name)
 
   for entry in _get_library_load_candidates(name, readable_name, env_var):
@@ -184,7 +185,7 @@ def _load_core_shared_library(): return _load_shared_library('hebi', 'HEBI Core'
 def _load_wrapper_shared_library(): return _load_shared_library('hebiWrapper', 'HEBI Core wrapper', 'HEBI_WRAPPER_LIB')
 
 
-def _find_linux_candidates(output: "List[str]", lib_base_path: str, maj_ver: int, min_ver: int, library: str):
+def _find_linux_candidates(output: 'list[str]', lib_base_path: str, maj_ver: int, min_ver: int, library: str):
   import re
   cpu = machine()
   py_exec_arch = architecture()[0]
@@ -213,7 +214,7 @@ def _find_linux_candidates(output: "List[str]", lib_base_path: str, maj_ver: int
   output.append(lib_path)
 
 
-def _find_mac_candidates(output: "List[str]", lib_base_path: str, maj_ver: str, library: str):
+def _find_mac_candidates(output: 'list[str]', lib_base_path: str, maj_ver: str, library: str):
   cpu = machine()
   if cpu == 'arm64':
     output.append(join(lib_base_path, 'osx_arm64', 'lib{}.{}.dylib'.format(library, maj_ver)))
@@ -223,7 +224,7 @@ def _find_mac_candidates(output: "List[str]", lib_base_path: str, maj_ver: str,
     output.append(join(lib_base_path, 'osx_amd64', 'lib{}.dylib'.format(library)))
 
 
-def _find_win_candidates(output: "List[str]", lib_base_path: str, library: str):
+def _find_win_candidates(output: 'list[str]', lib_base_path: str, library: str):
   cpu = machine()
   py_exec_arch = architecture()[0]
 
