@@ -1,9 +1,12 @@
-from typing import Any, Callable, Dict, Generic, List, Optional, TypeVar, Union
 from hebi._internal.utils import intern_string
 from weakref import ref, ReferenceType
 
 from ..utils import Counter
 
+import typing
+from typing import Generic, TypeVar
+if typing.TYPE_CHECKING:
+  from typing import Any, Callable
 
 ################################################################################
 # Unmanaged class wrappers
@@ -55,15 +58,15 @@ class UnmanagedSharedObject(object):
 
   __slots__ = ['_holder']
 
-  def __init__(self, internal: Any=None, on_delete: Callable[[Any], None]=(lambda _: None), existing: Optional['UnmanagedSharedObject']=None, isdummy: bool=False):
+  def __init__(self, internal: 'Any' = None, on_delete: 'Callable[[Any], None]' = (lambda _: None), existing: 'UnmanagedSharedObject | None' = None, isdummy: bool = False):
     class Proxy(object):
-      def __init__(self, internal=None, on_delete=None, proxy: Optional['Proxy']=None):
+      def __init__(self, internal=None, on_delete: 'Callable[[Any], None]' = (lambda _: None), proxy: 'Proxy | None' = None):
         if proxy is not None:
           with proxy._lock:
             if proxy._refcount.count == 0:
               raise RuntimeError('Object has already been finalized')
             self._lock = proxy._lock
-            self._internal: Any = proxy._internal
+            self._internal: 'Any' = proxy._internal
             self._on_delete = proxy._on_delete
             proxy._refcount.increment()
             self._refcount = proxy._refcount
@@ -72,7 +75,7 @@ class UnmanagedSharedObject(object):
           self._lock = Lock()
           self._internal = internal
           self._refcount = Counter()
-          self._on_delete: Callable[[Any], None] = on_delete
+          self._on_delete: 'Callable[[Any], None]' = on_delete
 
       def __del__(self):
         with self._lock:
@@ -108,7 +111,10 @@ class UnmanagedSharedObject(object):
   def _as_parameter_(self):
     return self._holder.get()
 
+
 ObjectT = TypeVar('ObjectT')
+
+
 class WeakReferenceContainer(Generic[ObjectT]):
   """Small wrapper around a weak reference.
 
@@ -123,8 +129,8 @@ class WeakReferenceContainer(Generic[ObjectT]):
       return ref
     raise RuntimeError('Reference no longer valid due to finalization')
 
-  def __init__(self, reference: ObjectT):
-    self._weak_ref: ReferenceType[ObjectT] = ref(reference)
+  def __init__(self, reference: 'ObjectT'):
+    self._weak_ref: 'ReferenceType[ObjectT]' = ref(reference)
 
 
 ################################################################################
@@ -132,14 +138,14 @@ class WeakReferenceContainer(Generic[ObjectT]):
 ################################################################################
 
 
-class FieldDetails(object):
+class FieldDetails:
   """
   TODO: Document
   """
 
-  __slots__ = ['_units', '_camel_case', '_pascal_case', '_snake_case', '_is_scalar']
+  __slots__ = ['_units', '_camel_case', '_pascal_case', '_snake_case']
 
-  def __init__(self, units, camel, pascal, snake, is_scalar):
+  def __init__(self, units: 'Any', camel: str, pascal: str, snake: str):
     if units is None:
       self._units = None
     else:
@@ -148,7 +154,6 @@ class FieldDetails(object):
     self._camel_case = intern_string(camel)
     self._pascal_case = intern_string(pascal)
     self._snake_case = intern_string(snake)
-    self._is_scalar = is_scalar
 
   @property
   def aliases(self):
@@ -160,7 +165,7 @@ class FieldDetails(object):
 
   @property
   def is_scalar(self):
-    return self._is_scalar
+    return True
 
   @property
   def camel_case(self):
@@ -186,10 +191,32 @@ class FieldDetails(object):
     return getattr(message_obj, self._snake_case)
 
 
-class NumberedFieldDetails(object):
+class NumberedFieldDetails:
   __slots__ = ['_getter_factory', '_units', '_base_camel_case', '_base_pascal_case', '_base_snake_case', '_numbered_fields']
 
-  def __init__(self, units, camel, pascal, snake, getter_factory, numbered_fields):
+  class Subfield:
+    __slots__ = ['_numbered_field_details', '_sub_field_str', '_getter_factory']
+
+    def __init__(self, numbered_field_details: 'NumberedFieldDetails', sub_field):
+
+      self._numbered_field_details = numbered_field_details
+      self._sub_field_str = str(sub_field)
+      self._getter_factory = numbered_field_details._getter_factory(sub_field)
+
+    @property
+    def aliases(self):
+      return {self._numbered_field_details._base_camel_case + self._sub_field_str,
+              self._numbered_field_details._base_pascal_case + self._sub_field_str,
+              self._numbered_field_details._base_snake_case + self._sub_field_str}
+
+    @property
+    def units(self):
+      return self._numbered_field_details.units
+
+    def get_field(self, message_obj):
+      return self._getter_factory(message_obj)
+
+  def __init__(self, units, camel: str, pascal: str, snake: str, getter_factory, numbered_fields):
     if units is None:
       self._units = None
     else:
@@ -217,36 +244,11 @@ class NumberedFieldDetails(object):
     :class:`FieldDetails`.
     """
     num_fields = len(self._numbered_fields)
-    ret = dict()
-
-    base_camel_case = self._base_camel_case
-    base_pascal_case = self._base_pascal_case
-    base_snake_case = self._base_snake_case
-    base_units = self._units
 
+    ret: 'dict[Any, NumberedFieldDetails.Subfield]' = dict()
     for i in range(num_fields):
       sub_field = self._numbered_fields[i]
-      sub_field_getter = self._getter_factory(sub_field)
-      sub_field_str = str(sub_field)
-
-      class Subfield(object):
-        __slots__ = []
-
-        def __init__(self):
-          pass
-
-        @property
-        def aliases(self):
-          return {base_camel_case + sub_field_str, base_pascal_case + sub_field_str, base_snake_case + sub_field_str}
-
-        @property
-        def units(self):
-          return base_units
-
-        def get_field(self, message_obj):
-          return sub_field_getter(message_obj)
-
-      ret[sub_field] = Subfield()
+      ret[sub_field] = self.Subfield(self, sub_field)
 
     return ret
 
@@ -258,7 +260,7 @@ class EnumTraits(object):
 
   __slots__ = ['_as_parameter_', '_name', '_value', '_type']
 
-  def __init__(self, value, name):
+  def __init__(self, value: int, name: str):
     self._value = value
     self._name = intern_string(name)
     self._as_parameter_ = value
@@ -314,11 +316,10 @@ class MessageEnumTraits(EnumTraits):
   TODO: Document
   """
 
-  __slots__ = ['__allow_broadcast', '__products', '__substrates', '__not_broadcastable_reason', '__field_details']
+  __slots__ = ['__products', '__substrates', '__not_broadcastable_reason', '__field_details']
 
-  def __init__(self, value: int, name: str, field_details: Union[FieldDetails, NumberedFieldDetails, None] = None, allow_broadcast=True, not_bcastable_reason='', yields_dict=None):
+  def __init__(self, value: int, name: str, field_details: 'FieldDetails | NumberedFieldDetails | None' = None, not_bcastable_reason: 'str | None' = None, yields_dict=None):
     super(MessageEnumTraits, self).__init__(value, name)
-    self.__allow_broadcast = allow_broadcast
     self.__not_broadcastable_reason = not_bcastable_reason
     self.__products = yields_dict
     self.__field_details = field_details
@@ -336,7 +337,7 @@ class MessageEnumTraits(EnumTraits):
   def allow_broadcast(self):
     """Determines whether the given enum has the ability to broadcast the same
     value to all modules in a group."""
-    return self.__allow_broadcast
+    return self.__not_broadcastable_reason is not None
 
   @property
   def substrates(self):
@@ -357,19 +358,21 @@ class MessageEnumTraits(EnumTraits):
     return self.__field_details
 
   def __repr__(self):
-    if self.__allow_broadcast:
+    if self.allow_broadcast:
       return '{} (value={}, type={}), broadcastable'.format(self._name, self._value, self.type)
     return '{} (value={}, type={}), not broadcastable ({})'.format(self._name, self._value, self.type, self.__not_broadcastable_reason)
 
 
 T = TypeVar('T')
+
+
 class EnumType(Generic[T]):
   __slots__ = ["__name", "__values", "__int_to_value"]
 
-  def __init__(self, name: str, values: List[T]):
+  def __init__(self, name: str, values: 'list[T]'):
     self.__name = name
 
-    int_to_value: Dict[int, T] = dict()
+    int_to_value: 'dict[int, T]' = dict()
 
     for value in values:
       if not isinstance(value, EnumTraits):
@@ -379,7 +382,7 @@ class EnumType(Generic[T]):
         int_to_value[int(value)] = value
 
     self.__int_to_value = int_to_value
-    self.__values: List[T] = values
+    self.__values: 'list[T]' = values
 
   @property
   def name(self):
