@@ -8,6 +8,10 @@
 
 from .ffi import enums as _enums
 
+import typing
+if typing.TYPE_CHECKING:
+  from .ffi.wrappers import FieldDetails, NumberedFieldDetails
+
 
 _feedback_scalars = [
     _enums.FeedbackFloatBoardTemperature,
@@ -51,10 +55,10 @@ _feedback_scalars = [
     _enums.FeedbackIoBankF]
 
 
-_feedback_scalars_map = {}
+_feedback_scalars_map: 'dict[str, FieldDetails | NumberedFieldDetails.Subfield]' = {}
 
 
-def __add_fbk_scalars_field(field):
+def __add_fbk_scalars_field(field: 'FieldDetails | NumberedFieldDetails.Subfield'):
   for alias in field.aliases:
     _feedback_scalars_map[alias] = field
 
@@ -68,7 +72,7 @@ def __populate_fbk_scalars_map():
       # TODO: THIS IS TEMPORARY. FIX THIS BY DEFINING FIELD_DETAILS FOR ALL FIELDS ABOVE
       continue
 
-    if field.is_scalar:
+    if isinstance(field, FieldDetails):
       # Will be an instance of `MessageEnumTraits`
       __add_fbk_scalars_field(field)
     else:
@@ -80,7 +84,7 @@ def __populate_fbk_scalars_map():
 __populate_fbk_scalars_map()
 
 
-def get_field_info(field_name):
+def get_field_info(field_name: str):
   """Get the info object representing the given field name.
 
   The field binder is a lambda which accepts a group feedback instance and returns the input field name
