@@ -64,7 +64,7 @@ class Color(object):
   def opaque(self):
     return self.__a == 255
 
-  def alpha_blend(self, dst):
+  def alpha_blend(self, dst: 'Color'):
     """"This" instance refers to src (foreground)
 
     :param dst: destination color (background)
