@@ -7,6 +7,7 @@
 # -----------------------------------------------------------------------------
 
 
+import typing
 from atexit import register as __register
 from ctypes import CFUNCTYPE, c_size_t, c_void_p, c_char_p, byref
 import os
@@ -22,9 +23,8 @@ from . import type_utils
 
 _FeedbackHandlerFunction = CFUNCTYPE(None, c_void_p, c_void_p)
 
-import typing
 if typing.TYPE_CHECKING:
-  from typing import Callable, List, Optional
+  from typing import Callable
 
 
 class GroupDelegate(UnmanagedObject):
@@ -32,7 +32,7 @@ class GroupDelegate(UnmanagedObject):
 
   __slots__ = ['_c_callback', '_feedback_callbacks', '_number_of_modules', '__weakref__']
 
-  __instances: "List[ref[GroupDelegate]]" = list()
+  __instances: 'list[ref[GroupDelegate]]' = list()
 
   @staticmethod
   def destroy_all_instances():
@@ -42,7 +42,7 @@ class GroupDelegate(UnmanagedObject):
       except:
         pass
 
-  def __parse_to(self, timeout_ms: "Optional[float]"):
+  def __parse_to(self, timeout_ms: 'float | None'):
     if timeout_ms is None:
       return Group.DEFAULT_TIMEOUT_MS
     else:
@@ -90,7 +90,7 @@ class GroupDelegate(UnmanagedObject):
     GroupDelegate.__instances.append(ref(self))
 
     self._number_of_modules = int(api.hebiGroupGetSize(internal))
-    self._feedback_callbacks: "List[Callable[[GroupFeedback], None]]" = list()
+    self._feedback_callbacks: 'list[Callable[[GroupFeedback], None]]' = list()
 
   @property
   def size(self):
@@ -122,10 +122,10 @@ class GroupDelegate(UnmanagedObject):
     if api.hebiGroupSetCommandLifetime(self, value) != enums.StatusSuccess:
       raise RuntimeError('Could not set command lifetime to {}'.format(value))
 
-  def send_command(self, group_command: "GroupCommand") -> bool:
+  def send_command(self, group_command: 'GroupCommand') -> bool:
     return api.hebiGroupSendCommand(self, group_command) == enums.StatusSuccess
 
-  def send_command_with_acknowledgement(self, group_command: "GroupCommand", timeout_ms=None) -> bool:
+  def send_command_with_acknowledgement(self, group_command: 'GroupCommand', timeout_ms=None) -> bool:
     timeout_ms = self.__parse_to(timeout_ms)
     status = api.hebiGroupSendCommandWithAcknowledgement(self, group_command, timeout_ms)
     return status == enums.StatusSuccess
@@ -133,10 +133,10 @@ class GroupDelegate(UnmanagedObject):
   def send_feedback_request(self):
     return api.hebiGroupSendFeedbackRequest(self) == enums.StatusSuccess
 
-  def get_next_feedback(self, timeout_ms=None, reuse_fbk: "Optional[GroupFeedback]"=None):
+  def get_next_feedback(self, timeout_ms=None, reuse_fbk: 'GroupFeedback | None' = None):
     timeout_ms = self.__parse_to(timeout_ms)
     if reuse_fbk:
-      feedback = GroupFeedback(self._number_of_modules, reuse_fbk)
+      feedback = reuse_fbk
     else:
       feedback = GroupFeedback(self._number_of_modules)
 
@@ -146,7 +146,7 @@ class GroupDelegate(UnmanagedObject):
     else:
       return None
 
-  def request_info(self, timeout_ms: "Optional[float]"=None, reuse_info: "Optional[GroupInfo]"=None):
+  def request_info(self, timeout_ms: 'float | None' = None, reuse_info: 'GroupInfo | None' = None):
     timeout_ms = self.__parse_to(timeout_ms)
     if reuse_info is not None:
       info = GroupInfo(self._number_of_modules)
@@ -201,7 +201,7 @@ class GroupDelegate(UnmanagedObject):
       return None
     return LogFile(c_log)
 
-  def add_feedback_handler(self, handler: "Callable[[GroupFeedback], None]"):
+  def add_feedback_handler(self, handler: 'Callable[[GroupFeedback], None]'):
     if not callable(handler):
       raise ValueError('handler was not callable')
     if handler in self._feedback_callbacks:
@@ -324,7 +324,7 @@ class Group:
     """
     self.__delegate.command_lifetime = value
 
-  def send_command(self, group_command: "GroupCommand"):
+  def send_command(self, group_command: 'GroupCommand'):
     """Send a command to the given group without requesting an acknowledgement.
     This is appropriate for high-frequency applications.
 
@@ -336,7 +336,7 @@ class Group:
     """
     return self.__delegate.send_command(group_command)
 
-  def send_command_with_acknowledgement(self, group_command: "GroupCommand", timeout_ms: "Optional[int]"=None) -> bool:
+  def send_command_with_acknowledgement(self, group_command: 'GroupCommand', timeout_ms: 'int | None' = None) -> bool:
     """Send a command to the given group, requesting an acknowledgement of
     transmission to be sent back.
 
@@ -371,7 +371,7 @@ class Group:
     """
     return self.__delegate.send_feedback_request()
 
-  def get_next_feedback(self, timeout_ms: "Optional[float]"=None, reuse_fbk: "Optional[GroupFeedback]"=None):
+  def get_next_feedback(self, timeout_ms: 'float | None' = None, reuse_fbk: 'GroupFeedback | None' = None):
     """Returns the most recently stored feedback from a sent feedback request,
     or the next one received (up to the requested timeout).
 
@@ -397,7 +397,7 @@ class Group:
     """
     return self.__delegate.get_next_feedback(timeout_ms, reuse_fbk)
 
-  def request_info(self, timeout_ms: "Optional[float]"=None, reuse_info: "Optional[GroupInfo]"=None):
+  def request_info(self, timeout_ms: 'float | None' = None, reuse_info: 'GroupInfo | None' = None):
     """Request info from the group, and store it in the passed-in info object.
 
     :param timeout_ms: The maximum amount of time to wait, in milliseconds.
@@ -417,7 +417,7 @@ class Group:
     """
     return self.__delegate.request_info(timeout_ms, reuse_info)
 
-  def start_log(self, directory: "Optional[str]"=None, name: "Optional[str]"=None, mkdirs: bool=False):
+  def start_log(self, directory: 'str | None' = None, name: 'str | None' = None, mkdirs: bool = False):
     """Start logging information and feedback from this group.
 
     If a log file was already started before this (and not stopped using :meth:`.stop_log`),
@@ -466,7 +466,7 @@ class Group:
     """
     return self.__delegate.stop_log()
 
-  def add_feedback_handler(self, handler: "Callable[[GroupFeedback], None]"):
+  def add_feedback_handler(self, handler: 'Callable[[GroupFeedback], None]'):
     """Adds a handler function to be called by the internal feedback request
     thread.
 
