@@ -14,8 +14,9 @@ from .utils import CaseInvariantString, intern_string
 
 import typing
 if typing.TYPE_CHECKING:
-  from typing import Dict, Any
+  from typing import Any
   import numpy.typing as npt
+  from .ffi.wrappers import EnumTraits
 
 neg_half_pi = pi*-0.5
 
@@ -68,11 +69,11 @@ class ActuatorDesc(object):
   def __init__(self, name, mass, inertia, com_xyz, input_to_axis_xyz):
     self._name = name
     self._mass = mass
-    self._inertia: "npt.NDArray[np.float64]" = np.array(inertia, dtype=np.float64)
+    self._inertia: 'npt.NDArray[np.float64]' = np.array(inertia, dtype=np.float64)
     self._com_xyz = com_xyz
     self._input_to_axis_xyz = input_to_axis_xyz
-    self._com: "npt.NDArray[np.float64]" = np.identity(4, np.float64)
-    self._input_to_axis: "npt.NDArray[np.float64]" = np.identity(4, np.float64)
+    self._com: 'npt.NDArray[np.float64]' = np.identity(4, np.float64)
+    self._input_to_axis: 'npt.NDArray[np.float64]' = np.identity(4, np.float64)
 
     v = com_xyz
     set_translate(self._com, v[0], v[1], v[2])
@@ -131,7 +132,7 @@ class BracketParserMatch(object):
 
   __slots__ = ['_mount', '_parser']
 
-  def __init__(self, parser, mount):
+  def __init__(self, parser: 'BracketParser', mount: str):
     self._parser = parser
     self._mount = mount
 
@@ -172,7 +173,7 @@ class BracketParser(object):
 
   __slots__ = ['_mass', '_mounts', '_name']
 
-  def __init__(self, name, mounts, mass):
+  def __init__(self, name: str, mounts: 'list[str]', mass: float):
     self._name = intern_string(name)
     self._mounts = [intern_string(mount) for mount in mounts]
     self._mass = mass
@@ -204,25 +205,25 @@ class KinematicsParserTLS(local):
 
   def __init__(self):
     super(KinematicsParserTLS, self).__init__()
-    self.parsed_joint_strs = dict()
-    self.parsed_frame_type_strs: "Dict[str, Any]" = dict()
-    self.parsed_actuator_strs = dict()
-    self.parsed_link_strs = dict()
-    self.parsed_bracket_strs = dict()
+    self.parsed_joint_strs: 'dict[str, EnumTraits]' = dict()
+    self.parsed_frame_type_strs: 'dict[str, EnumTraits]' = dict()
+    self.parsed_actuator_strs: 'dict[str, Any]' = dict()
+    self.parsed_link_strs: 'dict[str, Any]' = dict()
+    self.parsed_bracket_strs: 'dict[str, Any]' = dict()
 
-  def get_joint(self, joint):
+  def get_joint(self, joint: str):
     return self.parsed_joint_strs.get(joint)
 
-  def set_joint(self, joint, value):
+  def set_joint(self, joint: str, value: 'EnumTraits'):
     self.parsed_joint_strs[joint] = value
 
   def get_frame_type(self, frame_type: str):
     return self.parsed_frame_type_strs.get(frame_type)
 
-  def set_frame_type(self, frame_type: str, value: "Any"):
+  def set_frame_type(self, frame_type: str, value: 'EnumTraits'):
     self.parsed_frame_type_strs[frame_type] = value
 
-  def get_actuator(self, actuator):
+  def get_actuator(self, actuator: str):
     return self.parsed_actuator_strs.get(actuator)
 
   def set_actuator(self, actuator, value):
@@ -349,15 +350,6 @@ def __assert_str(value, name='value'):
     raise TypeError('{} must be a str'.format(name))
 
 
-def __get_from_dict(value, dict_, in_type):
-  ret = dict_.get(value, None)
-  if ret is not None:
-    return ret
-  valid_type_str = "'" + "', '".join([str(entry) for entry in dict_.keys()]) + "'"
-  raise ValueError("{0} is not a valid {1}. ".format(value, in_type) +
-                   "Valid types are: {0}".format(valid_type_str))
-
-
 def parse_frame_type(value: str):
   tls_val = _parser_tls.get_frame_type(value)
   if tls_val is not None:
@@ -375,7 +367,7 @@ def parse_frame_type(value: str):
       raise e
 
 
-def parse_joint_type(value):
+def parse_joint_type(value: str):
   tls_val = _parser_tls.get_joint(value)
   if tls_val is not None:
     return tls_val
@@ -401,7 +393,7 @@ def parse_actuator(value: str):
   try:
     fixed_val = value.upper()
     tls_val = __actuators[fixed_val]
-    _parser_tls.set_frame_type(value, tls_val)
+    _parser_tls.set_actuator(value, tls_val)
     return tls_val, tls_val.com, tls_val.input_to_axis
   except Exception as e:
     __assert_str(value, 'actuator')
@@ -420,16 +412,16 @@ def parse_actuator_link(value, extension, twist):
 
   try:
     extension = float(extension)
-  except ValueError as v:
+  except ValueError:
     raise ValueError('cannot convert extension={} to a float'.format(extension))
-  except TypeError as t:
+  except TypeError:
     raise TypeError('cannot convert extension={} (type {}) to a float'.format(extension, type(extension)))
 
   try:
     twist = float(twist)
-  except ValueError as v:
+  except ValueError:
     raise ValueError('cannot convert twist={} to a float'.format(twist))
-  except TypeError as t:
+  except TypeError:
     raise TypeError('cannot convert twist={} (type {}) to a float'.format(twist, type(twist)))
 
   return extension, twist
@@ -493,12 +485,12 @@ def parse_bracket(bracket, mount):
 ################################################################################
 
 
-def actuator_str_to_enum(actuator):
+def actuator_str_to_enum(actuator: str):
   __assert_str(actuator, 'actuator')
-  actuator = CaseInvariantString(actuator)
-  if actuator not in __actuator_to_enum:
-    raise ValueError('Unknown actuator type {}'.format(actuator))
-  return __actuator_to_enum[actuator]
+  actuator_ci = CaseInvariantString(actuator)
+  if actuator_ci not in __actuator_to_enum:
+    raise ValueError('Unknown actuator type {}'.format(actuator_ci))
+  return __actuator_to_enum[actuator_ci]
 
 
 def bracket_str_to_enum(bracket, mount):
@@ -533,13 +525,10 @@ def end_effector_str_to_enum(end_effector):
 ################################################################################
 
 
-def _add_pure_ints(d):
-  to_add = list()
-  for key in d.keys():
-    if type(key) is not int:
-      to_add.append((int(key), d[key]))
-  for entry in to_add:
-    d[entry[0]] = entry[1]
+def _add_pure_ints(d: 'dict[Any, str]'):
+  to_add = [(int(key), val) for (key, val) in d.items() if type(key) is not int]
+  for k, v in to_add:
+    d[k] = v
 
 
 _add_pure_ints(__enum_to_actuator)
