@@ -2,8 +2,6 @@ from .ffi._message_types import GroupCommand, GroupFeedback
 from .group import Group
 from .graphics import Color
 
-from typing import Optional, Union
-
 
 class MobileIO(object):
   """Wrapper around a mobile IO controller."""
@@ -18,12 +16,12 @@ class MobileIO(object):
 
   def __repr__(self):
     def btn_repr(btn):
-      ret = '  Button {0}:'.format(btn)
-      return ret + ' {0} ({1})\n'.format(self.get_button_state(btn), self.get_button_diff(btn))
+      ret = f'  Button {btn}: {self.get_button_state(btn)} ({self.get_button_diff(btn)})\n'
+      return ret
 
     def axis_repr(axis):
-      ret = '  Axis {0}:'.format(axis)
-      return ret + '   {0}\n'.format(self.get_axis_state(axis))
+      ret = f'  Axis {axis}:   {self.get_axis_state(axis)}\n'
+      return ret
 
     ret = 'MobileIO:\n'
     for i in range(8):
@@ -32,7 +30,7 @@ class MobileIO(object):
       ret += axis_repr(i+1)
     return ret
 
-  def update(self, timeout_ms: Optional[float]=None):
+  def update(self, timeout_ms: 'float | None' = None):
     """Updates the button and axis values and state. Returns ``False`` if
     feedback could not be received.
 
@@ -40,7 +38,10 @@ class MobileIO(object):
     :return: ``True`` on success; ``False`` otherwise
     """
     # save button states before updating feedback
-    self._last_button_state = [self._fbk.io.b.get_int(i+1) for i in range(8)]
+    b_bank = self._fbk[0].io.b
+    for i in range(8):
+      self._last_button_state[i] = b_bank.get_int(i+1)
+
     if self._group.get_next_feedback(timeout_ms=timeout_ms, reuse_fbk=self._fbk) is None:
       return False
 
@@ -57,18 +58,18 @@ class MobileIO(object):
       # sliders
       self._cmd.io.a.set_float(i+1, None) # snap
       self._cmd.io.f.set_float(i+1, 0) # value
-      self._cmd.io.a.set_label(i+1, f"A{i+1}")
+      self._cmd.io.a.set_label(i+1, f'A{i+1}')
       # buttons
       self._cmd.io.b.set_int(i+1, 0) # mode
       self._cmd.io.e.set_int(i+1, 0) # output
-      self._cmd.io.b.set_label(i+1, f"B{i+1}")
+      self._cmd.io.b.set_label(i+1, f'B{i+1}')
     self._cmd.clear_log = True
     self._cmd.led.color = 'transparent'
     res = self._group.send_command_with_acknowledgement(self._cmd)
     self._cmd.clear()
     return res
 
-  def get_button_diff(self, index: int) -> int:
+  def get_button_diff(self, index: int):
     """Retrieve the current diff of the specified button.
 
     Note that this method uses 1-indexing.
@@ -81,7 +82,7 @@ class MobileIO(object):
     """
     return self.get_button_state(index) - self._last_button_state[index-1]
 
-  def get_button_state(self, index: int) -> bool:
+  def get_button_state(self, index: int):
     """Retrieve the current (pressed/unpressed) state of the specified button.
 
     Note that this method uses 1-indexing.
@@ -93,7 +94,7 @@ class MobileIO(object):
     """
     if index < 1 or index > 8:
       raise IndexError("index must be between 1 and 8 inclusive")
-    return bool(self._fbk.io.b.get_int(index))
+    return bool(self._fbk[0].io.b.get_int(index))
 
   def get_axis_state(self, index: int) -> float:
     """Retrieve the current state of the specified axis.
@@ -107,9 +108,9 @@ class MobileIO(object):
     """
     if index < 1 or index > 8:
       raise IndexError("index must be between 1 and 8 inclusive")
-    return self._fbk.io.a.get_float(index)
+    return self._fbk[0].io.a.get_float(index)
 
-  def set_snap(self, slider: int, value: float) -> bool:
+  def set_snap(self, slider: int, value: float):
     """Set the snap position on a slider.
 
     Note that this method uses 1-indexing.
@@ -143,7 +144,7 @@ class MobileIO(object):
     self._cmd.io.f.set_float(slider, value)
     return self._group.send_command_with_acknowledgement(self._cmd)
 
-  def set_button_mode(self, button: int, value: Union[int, str]):
+  def set_button_mode(self, button: int, value: 'int | str'):
     """Set the mode of the specified button to momentary or toggle.
 
     Note that this method uses 1-indexing.
@@ -189,7 +190,7 @@ class MobileIO(object):
     self._cmd.io.e.set_int(button, value)
     return self._group.send_command_with_acknowledgement(self._cmd)
 
-  def set_led_color(self, color: Union[Color, int, str], blocking: bool=True):
+  def set_led_color(self, color: 'Color | int | str', blocking: bool = True):
     """Set the edge led color.
 
     :param color: The color to which the edge color is set. Certain strings are recognized as colors.
@@ -207,7 +208,7 @@ class MobileIO(object):
       return self._group.send_command_with_acknowledgement(self._cmd)
     return self._group.send_command(self._cmd)
 
-  def add_text(self, message: str, blocking: bool=True):
+  def add_text(self, message: str, blocking: bool = True):
     """Append a message to the text display.
 
     :param message: The string to append to the display
@@ -229,7 +230,7 @@ class MobileIO(object):
     self._cmd.append_log = None
     return retval
 
-  def clear_text(self, blocking: bool=True):
+  def clear_text(self, blocking: bool = True):
     """Clear the text display.
 
     :param blocking: If ``True``, block for acknowledgement from the device. Otherwise, return as quickly as possible.
@@ -239,23 +240,27 @@ class MobileIO(object):
     :return: ``True`` if the device received the command and successfully sent an acknowledgement; ``False`` otherwise.
     """
     self._cmd.clear_log = True
+    retval = None
     if blocking:
-      return self._group.send_command_with_acknowledgement(self._cmd)
-    return self._group.send_command(self._cmd)
+      retval = self._group.send_command_with_acknowledgement(self._cmd)
+    else:
+      retval = self._group.send_command(self._cmd)
+    self._cmd.clear_log = False
+    return retval
 
-  def set_button_label(self, button, label, blocking=True):
+  def set_button_label(self, button: int, label: str, blocking: bool = True):
     self._cmd.io.b.set_label(button, label)
     if blocking:
       return self._group.send_command_with_acknowledgement(self._cmd)
     return self._group.send_command(self._cmd)
 
-  def set_axis_label(self, axis, label, blocking=True):
+  def set_axis_label(self, axis: int, label: str, blocking: bool = True):
     self._cmd.io.a.set_label(axis, label)
     if blocking:
       return self._group.send_command_with_acknowledgement(self._cmd)
     return self._group.send_command(self._cmd)
 
-  def send_vibrate(self, blocking: bool=True):
+  def send_vibrate(self, blocking: bool = True):
     """Send a command to vibrate the device. Note that this feature depends on
     device support. If the device does not support programmatic vibrating, then
     this will be a no-op.
