@@ -21,7 +21,7 @@ class Trajectory(object):
 
   __slots__ = ['_trajectories', '_waypoint_times', '_number_of_waypoints', '_number_of_joints', '_start_time', '_end_time']
 
-  def __init__(self, trajectories, waypoint_times: "npt.NDArray[np.float64]", num_waypoints: int):
+  def __init__(self, trajectories, waypoint_times: 'npt.NDArray[np.float64]', num_waypoints: int):
     self._trajectories = trajectories
     self._waypoint_times = waypoint_times
     self._number_of_waypoints = num_waypoints
@@ -98,9 +98,9 @@ class Trajectory(object):
     velocity_val = c_double(0.0)
     acceleration_val = c_double(0.0)
 
-    position: "npt.NDArray[np.float64]" = np.zeros(self.number_of_joints, np.float64)
-    velocity: "npt.NDArray[np.float64]" = np.zeros(self.number_of_joints, np.float64)
-    acceleration: "npt.NDArray[np.float64]" = np.zeros(self.number_of_joints, np.float64)
+    position: 'npt.NDArray[np.float64]' = np.zeros(self.number_of_joints, np.float64)
+    velocity: 'npt.NDArray[np.float64]' = np.zeros(self.number_of_joints, np.float64)
+    acceleration: 'npt.NDArray[np.float64]' = np.zeros(self.number_of_joints, np.float64)
 
     for i, trajectory in enumerate(self._trajectories):
       passed_run =\
