@@ -10,7 +10,6 @@ from time import time
 import numpy as np
 
 from ._internal.ffi._message_types import GroupCommand, GroupFeedback
-from numpy import nan
 from math import atan2
 
 from . import robot_model as robot_model_api
@@ -18,13 +17,14 @@ from . import trajectory as trajectory_api
 
 import typing
 if typing.TYPE_CHECKING:
-  from typing import Callable, List, Optional, Union, Sequence, Any, Dict
+  from typing import Callable, Union, Sequence, Any
   import numpy.typing as npt
   from hebi._internal.group import Group
   from . import Lookup
   from .robot_model import RobotModel
   VectorType = Union[Sequence[float], npt.NDArray[np.float64]]
 
+
 class Arm(object):
   """"""
 
@@ -32,14 +32,16 @@ class Arm(object):
       '_get_current_time_s', '_last_time', '_group', '_robot_model',
       '_end_effector', '_trajectory', '_trajectory_start_time', '_masses',
       '_aux_times', '_aux', '_feedback', '_command', '_tmp_4x4d', '_plugins',
-      '_min_positions', '_max_positions')
+      '_min_positions', '_max_positions', '_com_jacobians')
 
-  def __init__(self, time_getter: "Callable[[], float]", group: "Group", robot_model: "RobotModel", end_effector: "Optional[EndEffector]"=None, plugins=None):
+  def __init__(self, time_getter: 'Callable[[], float]', group: 'Group', robot_model: 'RobotModel', end_effector: 'EndEffector | None' = None, plugins: 'list[ArmPlugin] | None' = None):
     self._get_current_time_s = time_getter
     self._group = group
     self._robot_model = robot_model
     self._end_effector = end_effector
-    self._plugins: "List[ArmPlugin]" = []
+    self._plugins: 'list[ArmPlugin]' = []
+
+    self._com_jacobians = np.empty((self._robot_model.get_frame_count('CoM'), 6, robot_model.dof_count), dtype=np.float64)
 
     size = group.size
 
@@ -49,16 +51,21 @@ class Arm(object):
     self._masses = robot_model.masses
 
     self._trajectory = None
-    self._trajectory_start_time = nan
+    self._trajectory_start_time = np.nan
 
-    self._min_positions = None
-    self._max_positions = None
+    self._min_positions = np.full(size, -np.inf)
+    self._max_positions = np.full(size, np.inf)
 
-    self._tmp_4x4d: npt.NDArray[np.float64] = np.identity(4, dtype=np.float64)
+    self._tmp_4x4d = np.identity(4, dtype=np.float64)
 
-    if plugins is not None:
-      for plugin in plugins:
-        self.add_plugin(plugin)
+    # Arms always have grav and dynamic comp plugins
+    if plugins is None:
+      plugins = [GravCompEffortPlugin(), DynamicCompEffortPlugin()]
+    else:
+      plugins = [GravCompEffortPlugin(), DynamicCompEffortPlugin()] + plugins
+
+    for plugin in plugins:
+      self.add_plugin(plugin)
 
   @property
   def size(self):
@@ -140,7 +147,7 @@ class Arm(object):
     """
     return self.goal_progress >= 1.0
 
-  def add_plugin(self, plugin: "ArmPlugin"):
+  def add_plugin(self, plugin: 'ArmPlugin'):
     """
     Adds the specified plugin to the arm.
     :meth:`ArmPlugin.on_associated` callback is invoked on the plugin specified.
@@ -155,7 +162,7 @@ class Arm(object):
     plugin.on_associated(self)
     self._plugins.append(plugin)
 
-  def load_gains(self, gains_file: str, attempts: int=5):
+  def load_gains(self, gains_file: str, attempts: int = 5):
     """Load the gains from the provided file and send the gains to the
     underlying modules in the group.
 
@@ -199,36 +206,36 @@ class Arm(object):
 
     command = self._command
     trajectory = self._trajectory
-    robot_model = self._robot_model
-    masses = self._masses
     end_effector = self._end_effector
     aux = []
 
     if trajectory is not None:
       t_traj = min(t - self._trajectory_start_time, trajectory.duration)
-      pos, vel, acc = trajectory.get_state(t_traj)
+      pos, vel, _ = trajectory.get_state(t_traj)
       aux = self.get_aux(t_traj)
     else:
-      pos = nan
-      vel = nan
-      acc = 0.0
+      pos = np.full(group.size, np.nan)
+      vel = np.full(group.size, np.nan)
+      #acc = np.zeros(group.size)
 
     command.position = pos
     command.velocity = vel
-
-    command.effort = _get_grav_comp_efforts(robot_model, feedback)
-
-    # TODO: Dynamic comp efforts
+    command.effort = 0.0
 
     res = True
 
     if end_effector is not None:
-      res = res and end_effector.update(aux)
+      res = end_effector.update(aux) and res
+
+    # Cached values for plugin speedup
+    self._robot_model.get_jacobians_mat('CoM',
+                                        self.last_feedback.position,
+                                        output=self._com_jacobians)
 
     for plugin in self._plugins:
       if plugin.enabled:
         # Only invoke the plugin if enabled
-        res and plugin.update(self)
+        res = plugin.update(self) and res
 
     return res
 
@@ -245,11 +252,11 @@ class Arm(object):
 
     return res
 
-  def set_end_effector(self, end_effector: "EndEffector"):
+  def set_end_effector(self, end_effector: 'EndEffector'):
     """Update the currently set end effector for the arm."""
     self._end_effector = end_effector
 
-  def set_goal(self, goal: "Goal"):
+  def set_goal(self, goal: 'Goal'):
     """Sets the current goal of the arm as described by the input waypoints.
 
     :param goal: Goal object representing waypoints of the goal
@@ -257,7 +264,12 @@ class Arm(object):
     """
     self.__set_goal(**goal.build())
 
-  def __set_goal(self, positions: "npt.NDArray[np.float64]", times=None, velocities: "Optional[npt.NDArray[np.float64]]"=None, accelerations: "Optional[npt.NDArray[np.float64]]"=None, aux: "Union[List[float], np.ndarray]" = None):
+  def __set_goal(self,
+                 positions: 'npt.NDArray[np.float64]',
+                 times=None,
+                 velocities: 'npt.NDArray[np.float64] | None' = None,
+                 accelerations: 'npt.NDArray[np.float64] | None' = None,
+                 aux: 'Sequence[float] | npt.NDArray[np.float64] | None' = None):
     """Sets the current goal of the arm as described by the input waypoints.
 
     :param positions: collection of one or more waypoints providing the position at each waypoint
@@ -332,7 +344,7 @@ class Arm(object):
 
     # Update aux state
     if aux is None or aux == []:
-      self._aux = np.array([], dtype=np.float64)
+      self._aux: 'npt.NDArray[np.float64]' = np.array([], dtype=np.float64)
       self._aux_times = []
     else:
       goal_aux = np.asarray(aux)
@@ -352,7 +364,7 @@ class Arm(object):
         # Update aux
         aux = np.empty((first_dim, second_dim), dtype=np.float64)
         # aux = self._aux
-        aux[:, 0] = nan
+        aux[:, 0] = np.nan
         aux[:, 1:] = goal_aux
         self._aux_times = waypoint_times
         self._aux = aux
@@ -379,7 +391,7 @@ class Arm(object):
     self._aux = aux
     self._aux_times = aux_times
 
-  def get_aux(self, t: float) -> np.ndarray:
+  def get_aux(self, t: float) -> 'npt.NDArray[np.float64]':
     """Retrieve the aux value at the given time point. If there are no aux
     values, an empty array is returned.
 
@@ -407,13 +419,15 @@ class Arm(object):
   def cancel_goal(self):
     """Removes any currently set goal."""
     self._trajectory = None
-    self._trajectory_start_time = nan
+    self._trajectory_start_time = np.nan
 
   @property
   def use_joint_limits(self):
-    return self._max_positions is not None and self._min_positions is not None
+    has_max = any(np.isfinite(self._max_positions))
+    has_min = any(np.isfinite(self._min_positions))
+    return has_max or has_min
 
-  def set_joint_limits(self, min_positions: "VectorType", max_positions: "VectorType"):
+  def set_joint_limits(self, min_positions: 'VectorType', max_positions: 'VectorType'):
     """Replace any currently set joint limits with the limits provided.
 
     :param min_positions: The minimum position limits. Must be a list and not a scalar.
@@ -428,15 +442,15 @@ class Arm(object):
     if any(np.isnan(min_positions)) or any(np.isnan(max_positions)):
       raise ValueError("Input must be non-nan")
 
-    self._min_positions: "Optional[npt.NDArray[np.float64]]" = np.asarray(min_positions)
-    self._max_positions: "Optional[npt.NDArray[np.float64]]" = np.asarray(max_positions)
+    self._min_positions: 'npt.NDArray[np.float64]' = np.asarray(min_positions)
+    self._max_positions: 'npt.NDArray[np.float64]' = np.asarray(max_positions)
 
   def clear_joint_limits(self):
     """Removes any currently set joint limits."""
-    self._min_positions = None
-    self._max_positions = None
+    self._min_positions = np.full(self.size, -np.inf)
+    self._max_positions = np.full(self.size, np.inf)
 
-  def FK(self, positions: "VectorType", **kwargs: "Any"):
+  def FK(self, positions: 'VectorType', **kwargs: 'Any'):
     """Retrieves the output frame of the end effector at the provided joint
     positions.
 
@@ -488,18 +502,16 @@ class Arm(object):
     else:
       ret = out
 
-    objective = robot_model_api.endeffector_position_objective(target_xyz)
+    objectives: 'list[robot_model_api._ObjectiveBase]' = []
+    objectives.append(robot_model_api.endeffector_position_objective(target_xyz))
 
-    kin = self._robot_model
     if self.use_joint_limits:
       # Add the `joint_limit_constraint` to the list of IK objectives
-      joint_objective = robot_model_api.joint_limit_constraint(self._min_positions,
-                                                               self._max_positions)
-      kin.solve_inverse_kinematics(initial_position, objective,
-                                   joint_objective, output=ret)
-    else:
-      kin.solve_inverse_kinematics(initial_position, objective,
-                                   output=ret)
+      objectives.append(robot_model_api.joint_limit_constraint(self._min_positions,
+                                                               self._max_positions))
+
+    self._robot_model.solve_inverse_kinematics(initial_position, *objectives,
+                                               output=ret)
 
     return ret
 
@@ -520,19 +532,25 @@ class Arm(object):
     else:
       ret = out
 
-    objectives: "List[robot_model_api._ObjectiveBase]" = []
+    objectives: 'list[robot_model_api._ObjectiveBase]' = []
     objectives.append(robot_model_api.endeffector_position_objective(target_xyz))
     objectives.append(robot_model_api.endeffector_tipaxis_objective(tip_axis))
 
-    if self.use_joint_limits:
+    if self.use_joint_limits and self._min_positions is not None and self._max_positions is not None:
       # Add the `joint_limit_constraint` to the list of IK objectives
       objectives.append(robot_model_api.joint_limit_constraint(self._min_positions,
                                                                self._max_positions))
 
-    return self._robot_model.solve_inverse_kinematics(initial_position, *objectives,
-                                                      output=ret)
+    self._robot_model.solve_inverse_kinematics(initial_position, *objectives,
+                                               output=ret)
 
-  def ik_target_xyz_so3(self, initial_position: "VectorType", target_xyz: "VectorType", orientation: "npt.NDArray[np.float64]", out: "Optional[npt.NDArray[np.float64]]"=None):
+    return ret
+
+  def ik_target_xyz_so3(self,
+                        initial_position: 'VectorType',
+                        target_xyz: 'VectorType',
+                        orientation: 'npt.NDArray[np.float64]',
+                        out: 'npt.NDArray[np.float64] | None' = None):
     """Solve for the joint space positions such that the end effector is near
     the target xyz position in space with the specified SO3 orientation.
 
@@ -548,17 +566,19 @@ class Arm(object):
     else:
       ret = out
 
-    objectives: "List[robot_model_api._ObjectiveBase]" = []
+    objectives: 'list[robot_model_api._ObjectiveBase]' = []
     objectives.append(robot_model_api.endeffector_position_objective(target_xyz))
     objectives.append(robot_model_api.endeffector_so3_objective(orientation))
 
-    if self.use_joint_limits:
+    if self.use_joint_limits and self._min_positions is not None and self._max_positions is not None:
       # Add the `joint_limit_constraint` to the list of IK objectives
       objectives.append(robot_model_api.joint_limit_constraint(self._min_positions,
                                                                self._max_positions))
 
-    return self._robot_model.solve_inverse_kinematics(initial_position, *objectives,
-                                                      output=ret)
+    self._robot_model.solve_inverse_kinematics(initial_position, *objectives,
+                                               output=ret)
+
+    return ret
 
 
 class Goal(object):
@@ -571,17 +591,17 @@ class Goal(object):
                '_waypoints_valid', '_result', '_user_time', '_user_aux')
 
   def __init__(self, dof_count: int):
-    self._times = []
-    self._positions = []
-    self._velocities = []
-    self._accelerations = []
+    self._times: 'list[float]' = []
+    self._positions: 'list[VectorType | None]' = []
+    self._velocities: 'list[VectorType | None]' = []
+    self._accelerations: 'list[VectorType | None]' = []
     self._aux = []
     self._dof_count = dof_count
     self._waypoints_valid = False
     self._user_time = False
     self._user_aux = False
 
-    res: Dict[str, Any] = dict()
+    res: 'dict[str, Any]' = dict()
     res['times'] = None
     res['positions'] = None
     res['velocities'] = None
@@ -635,22 +655,22 @@ class Goal(object):
       acc_val = in_acc[i]
 
       if pos_val is None:
-        if i == 0 or i == last_waypoint:
+        if i == last_waypoint:
           pos_val = 0.0
         else:
-          pos_val = nan
+          pos_val = np.nan
 
       if vel_val is None:
-        if i == 0 or i == last_waypoint:
+        if i == last_waypoint:
           vel_val = 0.0
         else:
-          vel_val = nan
+          vel_val = np.nan
 
       if acc_val is None:
-        if i == 0 or i == last_waypoint:
+        if i == last_waypoint:
           acc_val = 0.0
         else:
-          acc_val = nan
+          acc_val = np.nan
 
       positions[:, i] = pos_val
       velocities[:, i] = vel_val
@@ -684,7 +704,13 @@ class Goal(object):
 
     return self
 
-  def add_waypoint(self, t: "Optional[float]"=None, position: "Optional[VectorType]"=None, velocity: "Optional[VectorType]"=None, acceleration: "Optional[VectorType]"=None, aux: "Optional[Union[float, VectorType]]"=None, time_relative: bool=True):
+  def add_waypoint(self,
+                   t: 'float | None' = None,
+                   position: 'VectorType | None' = None,
+                   velocity: 'VectorType | None' = None,
+                   acceleration: 'VectorType | None' = None,
+                   aux: 'float | VectorType | None' = None,
+                   time_relative: bool = True):
     """
 
     :param t: The time point associated with this waypoint. `time_relative`
@@ -715,75 +741,70 @@ class Goal(object):
     :type time_relative:  bool
     """
 
-    waypoint_count = self.waypoint_count
     dof_count = self._dof_count
     user_time = self._user_time
     user_aux = self._user_aux
 
-    if waypoint_count > 0:
-      if t is not None and not user_time:
-        # ``t`` was not provided previously but now is
-        raise ValueError("waypoint times must be defined for all waypoints or none")
-      elif t is None and user_time:
-        # ``t`` was provided previously but not here
-        raise ValueError("waypoint times must be defined for all waypoints or none")
-
-      if aux is not None and not user_aux:
-        # ``aux`` was not provided previously but now is
-        raise ValueError("waypoint aux must be defined for all waypoints or none")
-      elif aux is None and user_aux:
-        # ``aux`` was provided previously but not here
-        raise ValueError("waypoint aux must be defined for all waypoints or none")
-
-    if user_time:
-      if time_relative:
-        t += self._times[-1]
-      # Check edge cases with time
-      if self._times[-1] >= t:
-        raise ValueError("waypoint times must be monotonically increasing")
-      elif not np.isfinite(t):
-        raise ValueError("waypoint times must be finite")
-
-    if position is None and velocity is None and acceleration is None:
-      # At least one derivative of position, or position itself must be passed in for each waypoint
-      raise ValueError("At least one of the following arguments must be non-null: position, velocity, acceleration")
-
-    if position is not None:
-      pos_val = position
-      if len(position) != dof_count:
-        raise ValueError("length of position input must be equal to dof_count")
-    else:
-      pos_val = None
-
-    if velocity is not None:
-      vel_val = velocity
-      if len(velocity) != dof_count:
-        raise ValueError("length of velocity input must be equal to dof_count")
-    else:
-      vel_val = None
-
-    if acceleration is not None:
-      acc_val = acceleration
-      if len(acceleration) != dof_count:
-        raise ValueError("length of acceleration input must be equal to dof_count")
-    else:
-      acc_val = None
-
-    self._waypoints_valid = False
-    self._positions.append(pos_val)
-    self._velocities.append(vel_val)
-    self._accelerations.append(acc_val)
-
-    if waypoint_count == 0:
+    if self.waypoint_count == 0:
       # Set the rule for any additional waypoints
       user_time = t is not None
       user_aux = aux is not None
       self._user_time = user_time
       self._user_aux = user_aux
+    else:
+      if not user_time and t is not None:
+        # ``t`` was not provided previously but now is
+        raise ValueError("waypoint times must be defined for all waypoints or none")
+
+      if (aux is not None) != user_aux:
+        # ``aux`` was not provided previously but now is
+        # or
+        # ``aux`` was provided previously but not here
+        raise ValueError("waypoint aux must be defined for all waypoints or none")
+
+    if position is None and velocity is None and acceleration is None:
+      # At least one derivative of position, or position itself must be passed in for each waypoint
+      raise ValueError("At least one of the following arguments must be non-null: position, velocity, acceleration")
+
+    pos_val = None
+    if position is not None:
+      pos_val = position
+      if len(position) != dof_count:
+        raise ValueError("length of position input must be equal to dof_count")
+
+    vel_val = None
+    if velocity is not None:
+      vel_val = velocity
+      if len(velocity) != dof_count:
+        raise ValueError("length of velocity input must be equal to dof_count")
+
+    acc_val = None
+    if acceleration is not None:
+      acc_val = acceleration
+      if len(acceleration) != dof_count:
+        raise ValueError("length of acceleration input must be equal to dof_count")
 
     if user_time:
+      if t is None:
+        raise ValueError("waypoint times must be defined for all waypoints or none")
+      curr_time = 0.0
+      if self.waypoint_count > 0:
+        curr_time = self._times[-1]
+      if time_relative:
+        t += curr_time
+      # Check edge cases with time
+      if curr_time >= t:
+        raise ValueError("waypoint times must be monotonically increasing")
+      elif not np.isfinite(t):
+        raise ValueError("waypoint times must be finite")
+
       self._times.append(t)
 
+    self._waypoints_valid = False
+    self._positions.append(pos_val)
+    self._velocities.append(vel_val)
+    self._accelerations.append(acc_val)
+
     if user_aux:
       self._aux.append(aux)
 
@@ -796,7 +817,7 @@ class EndEffector(object):
 
   def __init__(self): pass
 
-  def update(self, aux_state: "Union[float, Sequence[float], npt.NDArray[np.float64]]"):
+  def update(self, aux_state: 'float | VectorType') -> bool:
     """Update the aux state of the end effector.
 
     :param aux_state: a scalar number (`int` or `float`) or list of numbers.
@@ -806,7 +827,7 @@ class EndEffector(object):
     """
     return True
 
-  def send(self):
+  def send(self) -> bool:
     """Sends the currently pending command to the end effector.
 
     :return: ``True`` on success; otherwise ``False``
@@ -821,7 +842,7 @@ class Gripper(EndEffector):
 
   __slots__ = ('_state', '_close_effort', '_open_effort', '_group', '_command')
 
-  def __init__(self, group: "Group", close_effort: float, open_effort: float):
+  def __init__(self, group: 'Group', close_effort: float, open_effort: float):
     self._group = group
     self._close_effort = close_effort
     self._open_effort = open_effort
@@ -873,7 +894,7 @@ class Gripper(EndEffector):
     """
     return self._group.send_command(self._command)
 
-  def update(self, aux: "Union[float, npt.NDArray[np.float64]]"):
+  def update(self, aux: 'float | npt.NDArray[np.float64]'):
     """Update the state of the gripper.
 
     :param aux: The aux data. Can be a scalar value or a list of values.
@@ -900,7 +921,7 @@ class Gripper(EndEffector):
     self._state = val
     return True
 
-  def load_gains(self, gains_file: str, attempts: int=5):
+  def load_gains(self, gains_file: str, attempts: int = 5):
     """Load the gains from the provided file and send the gains to the gripper.
 
     This method requests acknowledgement from the gripper that the gains
@@ -956,6 +977,46 @@ class ArmPlugin(object):
     pass
 
 
+class GravCompEffortPlugin(ArmPlugin):
+  def on_associated(self, arm: Arm):
+    self.grav_efforts = np.empty(arm.size, dtype=np.float64)
+
+  def update(self, arm: Arm):
+    gravity = _gravity_from_quaternion(arm.last_feedback.orientation[0])
+    g_norm = np.linalg.norm(gravity)
+    if g_norm > 0.0:
+      gravity = gravity / g_norm * -9.81
+
+    arm.robot_model.get_grav_comp_efforts(arm.last_feedback.position,
+                                          gravity,
+                                          jacobians=arm._com_jacobians,
+                                          output=self.grav_efforts)
+    arm.pending_command.effort += self.grav_efforts
+
+    return True
+
+
+class DynamicCompEffortPlugin(ArmPlugin):
+  def on_associated(self, arm: Arm):
+    self.dyn_efforts = np.empty(arm.size, dtype=np.float64)
+
+  def update(self, arm: Arm):
+    # apply compensation torques for arm dynamics
+    if arm.trajectory is not None:
+      fbk_p = arm.last_feedback.position
+      t_traj = min(arm._last_time - arm._trajectory_start_time, arm.trajectory.duration)
+      p, v, a = arm.trajectory.get_state(t_traj)
+      arm.robot_model.get_dynamic_comp_efforts(fbk_p,
+                                               p,
+                                               v,
+                                               a,
+                                               jacobians=arm._com_jacobians,
+                                               output=self.dyn_efforts)
+      arm.pending_command.effort += self.dyn_efforts
+
+    return True
+
+
 class EffortOffset(ArmPlugin):
   """Plugin implementation used to offset the effort to be sent to the group.
 
@@ -963,22 +1024,14 @@ class EffortOffset(ArmPlugin):
   the group.
   """
 
-  __slots__ = ('_offset')
+  __slots__ = ('offset')
 
-  def __init__(self, offset: "npt.NDArray[np.float32]"):
-    self._offset = offset
-
-  @property
-  def offset(self):
-    return self._offset
-
-  @offset.setter
-  def offset(self, value):
-    self._offset = value
+  def __init__(self, offset: 'npt.NDArray[np.float32]'):
+    self.offset = offset
 
   def update(self, arm: Arm):
     cmd = arm.pending_command
-    cmd.effort = cmd.effort + self._offset
+    cmd.effort += self.offset
 
     return True
 
@@ -992,19 +1045,19 @@ class ImpedanceController(ArmPlugin):
       '_cmd_vel', '_fbk_pos', '_cmd_effort', '_fbk_vel', '_impedance_effort',
       '_kp', '_kd', 'gains_in_end_effector_frame')
 
-  def __init__(self, gains_in_end_effector_frame: bool=False):
-    self._jacobian_end_effector: "Optional[npt.NDArray[np.float64]]" = None
-    self._cmd_pos: "Optional[npt.NDArray[np.float64]]" = None
-    self._cmd_vel: "Optional[npt.NDArray[np.float64]]" = None
-    self._cmd_effort: "Optional[npt.NDArray[np.float64]]" = None
-    self._fbk_pos: "Optional[npt.NDArray[np.float64]]" = None
-    self._fbk_vel: "Optional[npt.NDArray[np.float64]]" = None
-    self._impedance_effort: "Optional[npt.NDArray[np.float64]]" = None
+  def __init__(self, gains_in_end_effector_frame: bool = False):
+    self._jacobian_end_effector: 'npt.NDArray[np.float64] | None' = None
+    self._cmd_pos: 'npt.NDArray[np.float64] | None' = None
+    self._cmd_vel: 'npt.NDArray[np.float64] | None' = None
+    self._cmd_effort: 'npt.NDArray[np.float64] | None' = None
+    self._fbk_pos: 'npt.NDArray[np.float64] | None' = None
+    self._fbk_vel: 'npt.NDArray[np.float64] | None' = None
+    self._impedance_effort: 'npt.NDArray[np.float64] | None' = None
 
-    self._desired_tip_fk: "npt.NDArray[np.float64]" = np.identity(4, dtype=np.float64)
-    self._actual_tip_fk: "npt.NDArray[np.float64]" = np.identity(4, dtype=np.float64)
-    self._kp: "npt.NDArray[np.float64]" = np.zeros(6, dtype=np.float64)
-    self._kd: "npt.NDArray[np.float64]" = np.zeros(6, dtype=np.float64)
+    self._desired_tip_fk: 'npt.NDArray[np.float64]' = np.identity(4, dtype=np.float64)
+    self._actual_tip_fk: 'npt.NDArray[np.float64]' = np.identity(4, dtype=np.float64)
+    self._kp: 'npt.NDArray[np.float64]'= np.zeros(6, dtype=np.float64)
+    self._kd: 'npt.NDArray[np.float64]' = np.zeros(6, dtype=np.float64)
     self.gains_in_end_effector_frame = gains_in_end_effector_frame
 
   def on_associated(self, arm: Arm):
@@ -1098,7 +1151,7 @@ class ImpedanceController(ArmPlugin):
     pos_error = self.__rotate(frame_rot.T, pos_error)
     vel_error = self.__rotate(frame_rot.T, vel_error)
 
-    wrench = np.multiply(self._kp, pos_error) + np.multiply(self._kd, vel_error)
+    wrench = self._kp * pos_error + self._kd * vel_error
     wrench = self.__rotate(frame_rot, wrench)
 
     impedance_effort = jacobian_end_effector.T @ wrench
@@ -1108,11 +1161,11 @@ class ImpedanceController(ArmPlugin):
 
     return True
 
-  def __rotate(self, R, vec):
+  def __rotate(self, R: 'npt.NDArray[np.float64]', vec: 'npt.NDArray[np.float64]'):
     res = np.zeros(6, dtype=np.float64)
     res[0:3] = R.dot(vec[0:3])  # linear component
     res[3:6] = R.dot(vec[3:6])  # rotational component
-    return vec
+    return res
 
 
 class DoubledJointMirror(ArmPlugin):
@@ -1121,7 +1174,7 @@ class DoubledJointMirror(ArmPlugin):
 
   __slots__ = ('_group', '_cmd', '_index')
 
-  def __init__(self, index, group: "Group"):
+  def __init__(self, index: int, group: 'Group'):
     if group.size != 1:
       raise ValueError("Expected a group of size 1")
     if index < 0:
@@ -1171,8 +1224,8 @@ def _rot2axisangle(R):
   return axis, atan2(y, R[:3, :3].diagonal().sum()-1)
 
 
-def _gravity_from_quaternion(quaternion):
-  output = np.empty(3, dtype=np.float64)
+def _gravity_from_quaternion(quaternion: 'Sequence[float]'):
+  output: 'npt.NDArray[np.float64]' = np.empty(3, dtype=np.float64)
 
   X = quaternion[1]
   Y = quaternion[2]
@@ -1193,18 +1246,6 @@ def _gravity_from_quaternion(quaternion):
   return output
 
 
-def _get_grav_comp_efforts(robot: robot_model_api.RobotModel, feedback: GroupFeedback):
-  """
-  :rtype:  np.ndarray
-  """
-  gravity = _gravity_from_quaternion(feedback.orientation[0])
-  g_norm = np.linalg.norm(gravity)
-  if g_norm > 0.0:
-    gravity = gravity / g_norm * -9.81
-
-  return robot.get_grav_comp_efforts(feedback.position, gravity)
-
-
 def _get_waypoint_times(times, num_waypoints, positions, velocities, accelerations):
   for i in range(num_waypoints):
     times[i] = 1.2 * i
@@ -1212,7 +1253,7 @@ def _get_waypoint_times(times, num_waypoints, positions, velocities, acceleratio
   return times
 
 
-def _repetitive_send_command_with_ack(group: "Group", cmd: "GroupCommand", attempts: int):
+def _repetitive_send_command_with_ack(group: 'Group', cmd: 'GroupCommand', attempts: int):
   for i in range(attempts):
     try:
       if group.send_command_with_acknowledgement(cmd):
@@ -1230,9 +1271,9 @@ def _repetitive_send_command_with_ack(group: "Group", cmd: "GroupCommand", attem
 _start_time = time()
 
 
-def create(families: "Union[str, List[str]]", names: "Optional[List[str]]"=None, command_lifetime: float=100, control_frequency: float=100.0,
-           hrdf_file: "Optional[str]"=None, robot_model: "Optional[robot_model_api.RobotModel]"=None, end_effector: "Optional[EndEffector]"=None,
-           time_getter: "Optional[Callable[[], float]]"=None, lookup: "Optional[Lookup]"=None) -> "Arm":
+def create(families: 'str | list[str]', names: 'list[str]| None' = None, command_lifetime: float = 100, control_frequency: float = 100.0,
+           hrdf_file: 'str | None' = None, robot_model: 'robot_model_api.RobotModel | None' = None, end_effector: 'EndEffector | None' = None,
+           time_getter: 'Callable[[], float] | None' = None, lookup: 'Lookup | None' = None) -> 'Arm':
   """Create an arm object based off of the provided kinematic representation.
 
   Examples::
@@ -1329,7 +1370,12 @@ def create(families: "Union[str, List[str]]", names: "Optional[List[str]]"=None,
   if names is not None:
     group = lookup.get_group_from_names(families, names)
   else:
-    group = lookup.get_group_from_family(families)
+    if isinstance(families, str):
+      family = families
+    else:
+      family = families[0]
+
+    group = lookup.get_group_from_family(family)
 
   if group is None:
     raise RuntimeError('Could not create arm. Check that family and names match actuators on the network.')
