@@ -13,11 +13,10 @@ from ._internal import math_utils as _math_utils
 from ._internal.trajectory import Trajectory as _Trajectory
 from ._internal.ffi import ctypes_func_defs as api
 
-from ._internal.ffi.ctypes_utils import byref, pointer_offset, to_double_ptr, cast_to_double_ptr, NULLPTR
+from ._internal.ffi.ctypes_utils import pointer_offset, c_double_p
 
 import typing
 if typing.TYPE_CHECKING:
-  from typing import Optional
   import numpy.typing as npt
 
 
@@ -28,16 +27,12 @@ def _check_dims_2d(arr, name, waypoints, joints):
     raise ValueError("Invalid dimensionality of {} matrix (expected {}, got {})".format(name, shape_expected, shape))
 
 
-def create_trajectory(time: "npt.ArrayLike", position: "npt.ArrayLike", velocity: "Optional[npt.ArrayLike]"=None, acceleration: "Optional[npt.ArrayLike]"=None):
+def create_trajectory(time: 'npt.ArrayLike', position: 'npt.ArrayLike', velocity: 'npt.ArrayLike | None' = None, acceleration: 'npt.ArrayLike | None' = None):
   """Creates a smooth trajectory through a set of waypoints (position velocity
   and accelerations defined at particular times). This trajectory wrapper
   object can create multi-dimensional trajectories (i.e., multiple joints
   moving together using the same time reference).
 
-  Deprecation notice: It is deprecated to pass a `str` in as a parameter
-  for any of the waypoint dimensions or time.
-  This functionality will be removed in a future release.
-
   :param time: A vector of desired times at which to reach each
                waypoint; this must be defined
                (and not ``None`` or ``nan`` for any element).
@@ -49,7 +44,7 @@ def create_trajectory(time: "npt.ArrayLike", position: "npt.ArrayLike", velocity
                    Any elements that are ``None`` or ``nan`` will be considered
                    free parameters when solving for a trajectory.
                    Values of ``+/-inf`` are not allowed.
-  :type position:  str, list, numpy.ndarray, ctypes.Array
+  :type position:  list, numpy.ndarray, ctypes.Array
 
   :param velocity: An optional matrix of velocity constraints at the
                    corresponding waypoints; should either be ``None``
@@ -57,7 +52,7 @@ def create_trajectory(time: "npt.ArrayLike", position: "npt.ArrayLike", velocity
                    Any elements that are ``None`` or ``nan`` will be considered
                    free parameters when solving for a trajectory.
                    Values of ``+/-inf`` are not allowed.
-  :type velocity:  NoneType, str, list, numpy.ndarray, ctypes.Array
+  :type velocity:  NoneType, list, numpy.ndarray, ctypes.Array
 
   :param acceleration: An optional matrix of acceleration constraints at
                        the corresponding waypoints; should either be ``None``
@@ -65,7 +60,7 @@ def create_trajectory(time: "npt.ArrayLike", position: "npt.ArrayLike", velocity
                        Any elements that are ``None`` or ``nan`` will be considered
                        free parameters when solving for a trajectory.
                        Values of ``+/-inf`` are not allowed.
-  :type acceleration:  NoneType, str, list, numpy.ndarray, ctypes.Array
+  :type acceleration:  NoneType, list, numpy.ndarray, ctypes.Array
 
   :return: The trajectory. This will never be ``None``.
   :rtype: Trajectory
@@ -102,8 +97,11 @@ def create_trajectory(time: "npt.ArrayLike", position: "npt.ArrayLike", velocity
     velocity[:, -1] = 0
 
   velocity = np.asarray(velocity, np.float64)
+  if len(velocity.shape) == 1:
+    velocity = velocity.reshape((1, -1))
+
   shape_checker(velocity, 'velocity')
-  velocity_c = to_double_ptr(velocity.ravel())
+  velocity_c = velocity.ctypes.data_as(c_double_p)
   get_vel_offset = lambda i: pointer_offset(velocity_c, i * pointer_stride)
 
   if acceleration is None:
@@ -112,12 +110,15 @@ def create_trajectory(time: "npt.ArrayLike", position: "npt.ArrayLike", velocity
     acceleration[:, -1] = 0
 
   acceleration = np.asarray(acceleration, np.float64)
+  if len(acceleration.shape) == 1:
+    acceleration = acceleration.reshape((1, -1))
+
   shape_checker(acceleration, 'acceleration')
-  acceleration_c = to_double_ptr(acceleration.ravel())
+  acceleration_c = acceleration.ctypes.data_as(c_double_p)
   get_acc_offset = lambda i: pointer_offset(acceleration_c, i * pointer_stride)
 
-  time_c = to_double_ptr(time)
-  position_c = to_double_ptr(position.ravel())
+  time_c = time.ctypes.data_as(c_double_p)
+  position_c = position.ctypes.data_as(c_double_p)
   trajectories = [None] * joints
 
   for i in range(0, joints):
