@@ -6,13 +6,21 @@
 #
 # ------------------------------------------------------------------------------
 
-from typing import List, Union, Optional
 from ._internal import log_file as _log_file
 from ._internal import group as _group
 from ._internal import mobile_io as _mobile_io
 
 from os.path import isfile as _isfile
 
+import typing
+if typing.TYPE_CHECKING:
+  from typing import Union, Any
+  from ._internal.lookup import Lookup
+  from hebi import GroupFeedback
+  from ._internal.log_file import TimedGroupFeedback
+  from ._internal.trajectory import Trajectory
+  Loggable = Union[_log_file.LogFile, str]
+
 try:
   import imp
   imp.find_module('matplotlib')
@@ -49,7 +57,7 @@ def create_imitation_group(size):
   return _group.create_imitation_group(size)
 
 
-def load_log(file: str, load: bool=True):
+def load_log(file: str, load: bool = True):
   """Opens an existing log file.
 
   :param file: the path to an existing log file
@@ -80,9 +88,7 @@ def load_log(file: str, load: bool=True):
   return log
 
 
-Loggable = Union[_log_file.LogFile, str]
-
-def plot_logs(logs: Union[Loggable, List[Loggable]], fbk_field: str, figure_spec: Optional[int]=None, modules: Optional[List[int]]=None):
+def plot_logs(logs: 'Loggable | list[Loggable]', fbk_field: str, figure_spec: 'int | None' = None, modules: 'list[int] | None' = None):
   """Nicely formatted plotting of HEBI logs.
 
   :param logs: The log(s) (or file path to a log) to plot
@@ -106,7 +112,7 @@ def plot_logs(logs: Union[Loggable, List[Loggable]], fbk_field: str, figure_spec
   elif not isinstance(logs, list):
     raise TypeError('Parameter logs was of unexpected type {}'.format(type(logs).__name__))
 
-  logfiles: List[str] = []
+  logfiles: 'list[str]' = []
   # First build list of filenames
   for i, entry in enumerate(logs[:]):
     if isinstance(entry, _log_file.LogFile) and entry.filename is not None:
@@ -130,6 +136,9 @@ def plot_logs(logs: Union[Loggable, List[Loggable]], fbk_field: str, figure_spec
     else:
       plot_mask = modules
 
+    def get_y(entry: 'GroupFeedback | TimedGroupFeedback'):
+      return feedback_info.get_field(entry)[plot_mask]
+
     if figure_spec is None:
       fig = plt.figure()
     else:
@@ -145,10 +154,10 @@ def plot_logs(logs: Union[Loggable, List[Loggable]], fbk_field: str, figure_spec
 
     num_plots = len(plot_mask)
 
-    x_module_series = list()
-    y_module_series = list()
-    cmd_module_series = list()
-    diff_module_series = list()
+    x_module_series: 'list[list[Any]]' = list()
+    y_module_series: 'list[list[Any]]' = list()
+    cmd_module_series: 'list[list[Any]]' = list()
+    diff_module_series: 'list[list[Any]]' = list()
 
     for _ in range(num_plots):
       x_module_series.append(list())
@@ -156,7 +165,6 @@ def plot_logs(logs: Union[Loggable, List[Loggable]], fbk_field: str, figure_spec
       cmd_module_series.append(list())
       diff_module_series.append(list())
 
-    get_y = lambda entry: feedback_info.get_field(entry)[plot_mask]
     x_lim_max = 0
     x_lim_min = None
 
@@ -236,7 +244,7 @@ def plot_logs(logs: Union[Loggable, List[Loggable]], fbk_field: str, figure_spec
   plt.show()
 
 
-def plot_trajectory(trajectory, dt=0.01, figure_spec=None, legend=None):
+def plot_trajectory(trajectory: 'Trajectory', dt=0.01, figure_spec=None, legend=None):
   """Visualizes position, velocity, and acceleration of a trajectory.
 
   :param trajectory:
@@ -337,7 +345,7 @@ def clear_all_groups():
   GroupDelegate.destroy_all_instances()
 
 
-def create_mobile_io(lookup, family='HEBI', name='mobileIO'):
+def create_mobile_io(lookup: 'Lookup', family='HEBI', name='mobileIO'):
   """Create a :class:`hebi._internal.mobile_io.MobileIO` instance with the
   specified family and name.
 
