@@ -1,5 +1,8 @@
 from os.path import join, dirname
-from typing import Any, List, Optional
+
+import typing
+if typing.TYPE_CHECKING:
+  from typing import Any
 
 
 def parse_version(s: str):
@@ -13,7 +16,7 @@ def parse_version(s: str):
   r = re.compile(r"^(\d+)([a-zA-Z_0-9-]+)?$")
   patch_str = split[2]
   patch_parts = r.split(patch_str)
-  parts: List[str] = []
+  parts: 'list[str]' = []
   for entry in patch_parts:
     if entry != '':
       parts.append(entry)
@@ -26,7 +29,7 @@ def parse_version(s: str):
 
 
 class Version(object):
-  def __init__(self, maj: int, min: int, rev: int, suffix: Optional[str]=None):
+  def __init__(self, maj: int, min: int, rev: int, suffix: 'str | None' = None):
     """Suffix string must only contain the following:
 
       * Underscore
@@ -47,7 +50,7 @@ class Version(object):
   def __repr__(self):
     return 'Version(major: {0}, minor: {1}, patch: {2}, suffix: {3})'.format(self.major_version, self.minor_version, self.patch_version, self.suffix)
 
-  def __eq__(self, o: Any) -> bool:
+  def __eq__(self, o: 'Any') -> bool:
     if isinstance(o, Version):
       thiz_suffix = self._suffix or ''
       o_suffix = o._suffix or ''
@@ -61,7 +64,7 @@ class Version(object):
     else:
       return False
 
-  def __ne__(self, o: Any) -> bool:
+  def __ne__(self, o: 'Any') -> bool:
     if isinstance(o, Version):
       thiz_suffix = self._suffix or ''
       o_suffix = o._suffix or ''
@@ -72,7 +75,7 @@ class Version(object):
     else:
       return self != parse_version(o)
 
-  def __gt__(self, o: Any) -> bool:
+  def __gt__(self, o: 'Any') -> bool:
     if isinstance(o, Version):
       if self.major_version > o.major_version:
         return True
@@ -94,7 +97,7 @@ class Version(object):
     else:
       raise TypeError()
 
-  def __lt__(self, o: Any) -> bool:
+  def __lt__(self, o: 'Any') -> bool:
     if isinstance(o, Version):
       if self.major_version < o.major_version:
         return True
@@ -136,11 +139,11 @@ class Version(object):
 
 
 def py_version():
-  return parse_version("2.6.1")
+  return parse_version("2.7.1")
 
 
 def min_c_api_version():
-  return parse_version("2.3.0")
+  return parse_version("2.7.1")
 
 
 def loaded_c_api_version():
